/*
 * Copyright (c) 2007 Michal Kebrt
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * - Redistributions of source code must retain the above copyright
 *   notice, this list of conditions and the following disclaimer.
 * - Redistributions in binary form must reproduce the above copyright
 *   notice, this list of conditions and the following disclaimer in the
 *   documentation and/or other materials provided with the distribution.
 * - The name of the author may not be used to endorse or promote products
 *   derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

/** @addtogroup arm32qemu_icp GXemul
 *  @brief GXemul machine specific parts.
 *  @ingroup arm32
 * @{
 */
/** @file
 *  @brief GXemul peripheries drivers declarations.
 */

#ifndef KERN_arm32_QEMU_ICP_H_
#define KERN_arm32_QEMU_ICP_H_

#include <console/chardev.h>

/** Last interrupt number (beginning from 0) whose status is probed 
 * from interrupt controller
 */
#define QEMU_ICP_IRQC_MAX_IRQ		8

/** Timer frequency */
#define QEMU_ICP_TIMER_FREQ		100

/** Struct containing mappings of qemu_icp HW devices into kernel part 
 *  of virtual address space.
 */
typedef struct {
	uintptr_t videoram;
	uintptr_t kbd;
	uintptr_t rtc;
	uintptr_t rtc_freq;
	uintptr_t rtc_ack;
	uintptr_t irqc;
	uintptr_t irqc_mask;
	uintptr_t irqc_unmask;
	uintptr_t vga;
	uintptr_t cmcr;
} qemu_icp_hw_map_t;

extern void qemu_icp_hw_map_init(void);
extern void qemu_icp_console_init(devno_t devno);
extern void qemu_icp_release_console(void);
extern void qemu_icp_grab_console(void);
extern void qemu_icp_timer_irq_start(void);
extern void qemu_icp_debug_putc(char ch);
extern void qemu_icp_cpu_halt(void);
extern void qemu_icp_irq_exception(int exc_no, istate_t *istate);
extern size_t qemu_icp_get_memory_size(void);
extern uintptr_t qemu_icp_get_fb_address(void);
extern void qemu_icp_fb_init(void);
#endif

/** @}
 */
